String method implementations for GENT
This module provides built-in methods for string values, including length, trim, split, contains, and more.
Functions
- call_
string_ method - Call a method on a string value
String method implementations for GENT
This module provides built-in methods for string values, including length, trim, split, contains, and more.